summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDave <vdr@pickles.me.uk>2016-03-13 13:43:48 +0000
committerDave <vdr@pickles.me.uk>2016-03-13 13:43:48 +0000
commit01cae01c5e65309c01f28fac9beb8fa5e19525dc (patch)
tree7ad74eba252a2ddcb38c552d888849d4e35c51a3
parent66eb3072047a217ceb72562796106ab0fa132a2d (diff)
downloadvdrtva-01cae01c5e65309c01f28fac9beb8fa5e19525dc.tar.gz
vdrtva-01cae01c5e65309c01f28fac9beb8fa5e19525dc.tar.bz2
Change series link lifetime to 91 days (NORDIG spec).
-rw-r--r--TODO2
-rw-r--r--vdrtva-2.3.c6
-rw-r--r--vdrtva.c6
3 files changed, 6 insertions, 8 deletions
diff --git a/TODO b/TODO
index 64d6129..6b21f79 100644
--- a/TODO
+++ b/TODO
@@ -19,14 +19,12 @@ Remove reliance on VDR "Housekeeping" callback - causes problems when VDR is bus
Remove need to patch core VDR for accurate recordings.
Better compliance with NORDIG specification:
- - Series lifetime should be 91 days (14.3.3)
- Default Authority of a channel may change (14.3.3)
- VDR timers list should show if event is part of a series (14.3.3)
- Option to record series via CLI (14.3.3.1)
- Use CRIDs to offer better choice for late recording (14.3.13)
- Timer conflict resolution per spec (14.3.16.2)
-Fix data capture at startup for devices which have no RTC (eg Raspberry Pi).
Bugs:
Very rare crash 'pure virtual method called' in plugin - possibly solved.
diff --git a/vdrtva-2.3.c b/vdrtva-2.3.c
index efc79ab..76808ea 100644
--- a/vdrtva-2.3.c
+++ b/vdrtva-2.3.c
@@ -31,7 +31,7 @@ static const char *MAINMENUENTRY = "Series Links";
int collectionperiod; // Time to collect all CRID data (secs, default 600)
int lifetime; // Lifetime of series link recordings (default 99)
int priority; // Priority of series link recordings (default 99)
-int seriesLifetime; // Expiry time of a series link (default 30 days)
+int seriesLifetime; // Expiry time of a series link (default 91 days)
int updatetime; // Time to carry out the series link update HHMM (default 03:00)
bool checkCollisions; // Whether to test for collisions (assuming single DVB card)
bool captureComplete; // Flag set if initial CRID capture has completed.
@@ -91,7 +91,7 @@ cPluginvdrTva::cPluginvdrTva(void)
// VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
configDir = NULL;
Filter = NULL;
- seriesLifetime = 30 * SECSINDAY;
+ seriesLifetime = 91 * SECSINDAY;
priority = 99;
lifetime = 99;
collectionperiod = 10 * 60; //secs
@@ -113,7 +113,7 @@ const char *cPluginvdrTva::CommandLineHelp(void)
" -n --nocheck Do not check for timer collisions\n"
" -p n --priority=n Priority of new timers (default 99)\n"
" -s n --serieslifetime=n Days to remember a series after the last event\n"
- " (default 30)\n"
+ " (default 91)\n"
" -u HH:MM --updatetime=HH:MM Time to update series links (default 03:00)\n";
}
diff --git a/vdrtva.c b/vdrtva.c
index 07a06a2..71aed33 100644
--- a/vdrtva.c
+++ b/vdrtva.c
@@ -31,7 +31,7 @@ static const char *MAINMENUENTRY = "Series Links";
int collectionperiod; // Time to collect all CRID data (secs, default 600)
int lifetime; // Lifetime of series link recordings (default 99)
int priority; // Priority of series link recordings (default 99)
-int seriesLifetime; // Expiry time of a series link (default 30 days)
+int seriesLifetime; // Expiry time of a series link (default 91 days)
int updatetime; // Time to carry out the series link update HHMM (default 03:00)
bool checkCollisions; // Whether to test for collisions (assuming single DVB card)
bool captureComplete; // Flag set if initial CRID capture has completed.
@@ -91,7 +91,7 @@ cPluginvdrTva::cPluginvdrTva(void)
// VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
configDir = NULL;
Filter = NULL;
- seriesLifetime = 30 * SECSINDAY;
+ seriesLifetime = 91 * SECSINDAY;
priority = 99;
lifetime = 99;
collectionperiod = 10 * 60; //secs
@@ -113,7 +113,7 @@ const char *cPluginvdrTva::CommandLineHelp(void)
" -n --nocheck Do not check for timer collisions\n"
" -p n --priority=n Priority of new timers (default 99)\n"
" -s n --serieslifetime=n Days to remember a series after the last event\n"
- " (default 30)\n"
+ " (default 91)\n"
" -u HH:MM --updatetime=HH:MM Time to update series links (default 03:00)\n";
}